package videoautomat;
import sale.SaleProcess;
import sale.SalesPoint;
import users.ActionCapability;
import users.User;
import data.ooimpl.DataBasketImpl;
import data.ooimpl.StoringStockImpl;

/**
 * This class implements the <code>User</code> of this application. It contains a <code>StoringStock</code> for
 * storing the actually rented videos and holds the information which capabilities the user has.
 */
public class AutomatUser extends User {
	/**
	 * Key used to get the <code>ActionCapability</code> used to start a {@link SaleProcessAdmin}.
	 */
	public static final String CAPABILITY_ADMIN = "admin";
	/*
	 * The stock which holds the rented videos.
	 */
	private StoringStockImpl ss_videos;
	/**
	 * Constructs a new <code>AutomatUser</code>.
	 * 
	 * @param user_ID
	 *                  the ID of the new user
	 * @param admin
	 *                  boolean to decide, whether this user has administrator privileges or not
	 */
	public AutomatUser(String user_ID, char[] passWd, boolean admin) {
		super(user_ID);
		setPassWd(garblePassWD(passWd));
		ss_videos = new StoringStockImpl(user_ID, VideoShop.getVideoCatalog());
		ss_videos.addStockChangeListener(new StockChangeLogger(user_ID));
		setCapability(new ActionCapability(
			CAPABILITY_ADMIN,
			VideoShop.MSG_ACCESS,
			new sale.Action() {
			public void doAction(SaleProcess p, SalesPoint sp) throws Throwable {
				sp.runProcess(new SaleProcessAdmin(), new DataBasketImpl());
			}
		}, admin));
	}
	/**
	 * @return a <code>StoringStock</code> containing the rented {@link VideoCassette}s of this user
	 */
	public StoringStockImpl getVideoStock() {
		return ss_videos;
	}
}

