package videoautomat;
import java.util.Date;

import log.LogEntry;
import sale.Shop;
/**
 * This class implements a <code>LogEntry</code> that describes the rent or hand back of a video.
 */
public class LogEntryVideo extends LogEntry {

	/*
	 * The name of the user who rented or handed back a video.
	 */
	private String user_ID;

	/*
	 * The name of the relevant video.
	 */
	private String video_name;

	/*
	 * True if this entry logs a rent event, otherwise false.
	 */
	private boolean rented;

	/*
	 * The date of logging.
	 */
	private Date date;

	/**
	 * Constructs a new <code>LogEntryVideo</code> by the given params and the current date.
	 * 
	 * @param user_ID
	 *                  the ID of the relevant user
	 * @param video
	 *                  the name of the relevant video
	 * @param rented
	 *                  choose true if this entry should log a rent event, otherwise false
	 */
	public LogEntryVideo(String user_ID, String video, boolean rented) {
		this.user_ID = user_ID;
		this.video_name = video;
		this.rented = rented;
		date = (Date) Shop.getTheShop().getTimer().getTime();
	}

	/**
	 * @return a <code>String</code> representing whether who has rented or who gave back which video.
	 * 
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		String s = " gave back ";
		if (rented)
			s = " has rented ";
		return ("The user " + user_ID + s + video_name);
	}

	/**
	 * @return the date of logging.
	 * 
	 * @see log.LogEntry#getLogDate()
	 */
	public Date getLogDate() {
		return date;
	}
}
