package videoautomat;
import java.io.Serializable;

import log.LogEntry;
import log.Loggable;
/**
 * This class implements <code>Loggable</code> to achieve the logging of {@link LogEntryVideo}.
 */
public class LoggableImpl implements Loggable, Serializable {

	/*
	 * The name of the user relevant to the log.
	 */
	private String user_ID;

	/*
	 * The name of the relevant video.
	 */
	private String video_name;

	/*
	 * True if this Loggable logs a rent event, otherwise null.
	 */
	private boolean rented;

	/**
	 * Constructs a new <code>LoggableImpl</code>, that will log {@link LogEntryVideo}s.
	 * 
	 * @param user_ID
	 *                  the ID of the relevant user
	 * @param video
	 *                  the name of the relevant video
	 * @param rented
	 *                  true if this <code>Loggable</code> should log a rent event, otherwise false
	 */
	public LoggableImpl(String user_ID, String video, boolean rented) {
		this.user_ID = user_ID;
		this.video_name = video;
		this.rented = rented;
	}

	/**
	 * @return a {@link LogEntryVideo} describing the event.
	 * 
	 * @see log.Loggable#getLogData()
	 */
	public LogEntry getLogData() {
		return new LogEntryVideo(user_ID, video_name, rented);
	}
}
