package videoautomat;
import sale.Shop;
import users.UserManager;
import data.Catalog;
import data.CatalogItem;
import data.CountingStock;
import data.IntegerValue;
import data.NumberValue;
import data.QuoteValue;
import data.ooimpl.CatalogItemImpl;
import data.ooimpl.EUROCurrencyImpl;
import data.ooimpl.MoneyBagImpl;

/**
 * This class implements the start up of the whole application, it contains also the main void of
 * this app.
 *  
 */
public class MainClass {
	
	/**
	 * Represents the cost per day for renting a video.
	 */
	public static NumberValue RENT_VALUE_DAY = new IntegerValue(200);
	/**
	 * The main void of the application, starts up the automat.
	 * 
	 * @param arqs
	 *                  takes no effect
	 */

	public static void main(String arqs[]) {
		VideoShop shop = new VideoShop();
		Shop.setTheShop(shop);
		shop.start();
		shop.addSalesPoint(new VideoAutomat());
		initializeVideos();		
		initializeUsers();
		initializeMoney();
	}

	/**
	 * Method to initial add some coins to the {@link VideoShop}s <code>MoneyBag</code>.
	 *  
	 */
	public static void initializeMoney() {
		MoneyBagImpl mbi =
			(MoneyBagImpl) Shop.getTheShop().getStock(VideoShop.MB_MONEY);
		mbi.add(EUROCurrencyImpl.CENT_STCK_10, 100, null);
		mbi.add(EUROCurrencyImpl.CENT_STCK_20, 100, null);
		mbi.add(EUROCurrencyImpl.CENT_STCK_50, 100, null);
		mbi.add(EUROCurrencyImpl.EURO_STCK_1, 100, null);
		mbi.add(EUROCurrencyImpl.EURO_STCK_2, 50, null);
		mbi.add(EUROCurrencyImpl.EURO_SCHEIN_10, 100, null);
		mbi.add(EUROCurrencyImpl.EURO_SCHEIN_20, 10, null);
	}
	/**
	 * Method to initial add some videos to the {@link VideoShop}s <code>Stock</code>.
	 *  
	 */
	public static void initializeVideos() {
        
        Catalog videoCatalog = VideoShop.getVideoCatalog();
        CountingStock videoStock = VideoShop.getVideoStock(); 
		
        for (int i = 0; i < 10; i++) { 
			String s = "Video-" + i;
            CatalogItem video = new CatalogItemImpl(s,
                                      new QuoteValue(new IntegerValue(1500),new IntegerValue(3000))) {
                   // implementation of the inherited abstract method
                   protected CatalogItemImpl getShallowClone() {
                       return null;
                   }
             };
             
             videoCatalog.add(video, null);
			 videoStock.add(s, 5, null);
		}
	}

	/**
	 * Method to initial add some users to the global <code>UserManager</code>.
	 *  
	 */
	public static void initializeUsers() {
		UserManager.getGlobalUM().addUser(new AutomatUser("Administrator", new char[0], true));
		for (int i = 0; i < 10; i++) {
			UserManager.getGlobalUM().addUser(
				new AutomatUser("Customer" + i, new char[0], false));
		}
	}
}
