package videoautomat;

import sale.Gate;
import sale.SaleProcess;
import sale.SalesPoint;
import sale.UIGate;
import videoautomat.contentcreator.HandBackSTFSContentCreator;
import videoautomat.contentcreator.HandBackTTFSContentCreator;
import data.IntegerValue;
import data.NumberValue;
import data.StoringStock;
import data.ooimpl.MoneyBagImpl;
import data.ooimpl.StoringStockImpl;
import data.stdforms.SingleTableFormSheet;
import data.stdforms.TwoTableFormSheet;
import data.stdforms.twotableformsheet.SSSSStrategy;

/**
 * This class implements a <code>SaleProcess</code> to hand back the videos.
 * @author Alexander Herrmann
 */
public class SaleProcessHandBack extends SaleProcess {

    /*
     * Key of StoringStock to store temporary videos.
     */
	public static final String SS_TEMP_KEY = "ss_temp";

	/*
	 * Key of a MoneyBag to store temporary the change money
	 */
	public static final String MB_TEMP_KEY = "mb_temp";

	/*
	 * Key of a NumberValue representing the change money
	 */
	public static final String CHG_MONEY_KEY = "nv_change";

	/**
	 * Constructs a new <code>SaleProcessHandBack</code>
	 * 
	 */
	public SaleProcessHandBack() {
		super("SaleProcessGiveback");
	}

	/**
	 * Implementation of the inherited abstract method.
	 * 
	 * @return the <code>Gate</code> where the user will see his/her current rented videos.
	 * @see sale.SaleProcess#getInitialGate()
	 * @author Alexander Herrmann
	 */
	protected Gate getInitialGate() {
	    
	    // generate Gate
	    UIGate uig_video = new UIGate(null, null);
	    
	    getContext().setProcessData(SS_TEMP_KEY, new StoringStockImpl("temp", VideoShop.getVideoCatalog()));
	    getContext().setProcessData(MB_TEMP_KEY, new MoneyBagImpl("temp", VideoShop.getCurrency()));
	    getContext().setProcessData(CHG_MONEY_KEY, new IntegerValue(0));
	    
	    TwoTableFormSheet ttfs_handback =
	        TwoTableFormSheet.create(
	                "Give back a video",
	                ((AutomatUser) ((SalesPoint) this.getContext()).getUser()).getVideoStock(),
	                (StoringStock) getContext().getProcessData(SS_TEMP_KEY),
	                getBasket(),
	                uig_video,
	                null,
	                null,
	                new TEDVideoCassette(),
	                new TEDVideoCassette(),
	                new SSSSStrategy()
	                );
	    
	    ttfs_handback.addContentCreator(new HandBackTTFSContentCreator());
	    
		return uig_video;
	}
	
	public Gate restart()
	{
	    return getInitialGate();
	}

	/**
	 * @return the <code>Gate</code> where the user will see his/her change money.
	 * @author Alexander Herrmann
	 */
	public Gate getChangeGate() {
	    
	    // generate Gate
	    UIGate uig_change = new UIGate(null, null);
	    
	    SingleTableFormSheet stfs_change =
	        SingleTableFormSheet.create(
	                "Here is your change!",
	                (MoneyBagImpl) getContext().getProcessData(MB_TEMP_KEY),
	                uig_change,
	                getBasket());
	     
	    stfs_change.addContentCreator(new HandBackSTFSContentCreator(
	            (NumberValue) getContext().getProcessData(SaleProcessHandBack.CHG_MONEY_KEY)));
	    
		return uig_change;
	}

}
