package videoautomat;
import sale.Gate;
import sale.SaleProcess;
import sale.UIGate;
import sale.stdforms.MsgForm;
import users.UserManager;
import users.stdforms.LogOnForm;
import videoautomat.contentcreator.LogOnLOFContentCreator;
import videoautomat.contentcreator.LogOnMFContentCreator;
import videoautomat.contentcreator.LogOnSTFSContentCreator;
import data.stdforms.SingleTableFormSheet;

/**
 * This class implements a <code>SaleProcess</code> used to log on and choose which activity should follow.
 *  
 */
public class SaleProcessLogOn extends SaleProcess {
	
	/**
	 * Constructs a new <code>SaleProcessLogOn</code>
	 *  
	 */
	public SaleProcessLogOn() {
		super("SaleProcessLogOn");
	}

	/**
	 * Implementation of the inherited abstract method.
	 * 
	 * @return a <code>Gate</code> where the user selects it`s user-name and is asked for his/her password.
	 * 
	 * @see sale.SaleProcess#getInitialGate()
	 */
	protected Gate getInitialGate() {
	    
	    UIGate uig_log_on = new UIGate(null, null);

	    LogOnForm lof_initial = new LogOnForm(
	            "Are you a registered user?",
				"Select your user name!",
				"Enter your passphrase!",
				true,
				UserManager.getGlobalUM(),
				null,
				null);
	    
	    lof_initial.addContentCreator(new LogOnLOFContentCreator());
	    
	    uig_log_on.setFormSheet(lof_initial);

	    return uig_log_on;
	}
	
	public Gate restart()
	{
	    return getInitialGate();
	}
	
	
	/**
	 * @return a <code>Gate</code> that shows an error-message.
	 */
	public Gate getFaultGate() {
	    
	    UIGate uig_fault = new UIGate(null, null);
	    
	    MsgForm mf_fault = new MsgForm(
	            "Log on failed!",
				"You didn`t choose a user name or the passphrase didn`t match!");
	    
	    mf_fault.addContentCreator(new LogOnMFContentCreator());
	    
	    uig_fault.setFormSheet(mf_fault);
	    
	    return uig_fault;
	}

	/**
	 * @return a <code>Gate</code> where the user can select the next activity, like renting a video.
	 */
	public Gate getMainGate() {
	    
	    UIGate uig_main = new UIGate(null, null);
	    
	    SingleTableFormSheet stfs_main =
	        SingleTableFormSheet.create(
	                "Select an action!",
	                VideoShop.getVideoStock(),
	                uig_main,
	                false,
	                new TEDVideoStock());
	    
	    stfs_main.addContentCreator(new LogOnSTFSContentCreator(this));
	    
	    return uig_main;
	}
}
