package videoautomat;
import sale.Gate;
import sale.SaleProcess;
import sale.SalesPoint;
import sale.UIGate;
import sale.stdforms.FormSheetStrategy;
import videoautomat.contentcreator.RentConfirmFSContentCreator;
import videoautomat.contentcreator.RentPayFSContentCreator;
import videoautomat.contentcreator.RentTTFSContentCreator;
import data.DataBasketConditionImpl;
import data.MoneyBag;
import data.NumberValue;
import data.ooimpl.MoneyBagImpl;
import data.stdforms.SingleTableFormSheet;
import data.stdforms.TwoTableFormSheet;
import data.stdforms.twotableformsheet.CCSStrategy;
import data.stdforms.twotableformsheet.CSDBStrategy;
import data.swing.DefaultStoringStockDBETableEntryDescriptor;
/**
 * This class implements a <code>SaleProcess</code> used to rent videos.
 *  
 */
public class SaleProcessRent extends SaleProcess {
	/*
	 * Key of a Databasket-subbasket which contains the temporary removed videos of the VideoShops stock
	 */
	public static final String SUB_SHOP_VIDEO = "videos_cs";
	/*
	 * Key of Databasket-subbasket which contains the temporary added videos of the users-stock
	 */
    public static final String SUB_USER_VIDEO = "video_ss";
	/*
	 * Key of Databasket-subbasket which contains the temporary added money of the user
	 */
    public static final String SUB_TMP_MONEY = "money_temp";
	/*
	 * Key of Databasket-subbasket which contains the temporary removed money of the VideoShops MoneyBag
	 */
    public static final String SUB_SHOP_MONEY = "money_shop";


	
    /** Key to the temp money bag for the porcess data of the process context */
    public static final String MB_TEMP_KEY = "mb_temp";    
	
    
    public static final String SUM_KEY = "nv_sum";

	/**
	 * Constructs a new SaleProcessRent
	 *  
	 */
	public SaleProcessRent() {
		super("SaleProcessRent");
	}
	/**
	 * Implementation of the inherited abstract method.
	 * 
	 * @return a <code>Gate</code> where the user makes a selection
	 * 
	 * @see sale.SaleProcess#getInitialGate()
	 */
	protected Gate getInitialGate() {
	    getContext().setProcessData(MB_TEMP_KEY, new MoneyBagImpl("mb_user", VideoShop.getCurrency()));        
       
		getBasket().setCurrentSubBasket(SUB_SHOP_VIDEO);
		CSDBStrategy csdbs = new CSDBStrategy();
		csdbs.setErrorHandler(FormSheetStrategy.MSG_POPUP_ERROR_HANDLER);
        
		// UIGate erzeugen
        UIGate uig_offer = new UIGate(null, null);
        
		TwoTableFormSheet ttfs_rent =
           TwoTableFormSheet.create(
                    "Choose your videos!",
                    VideoShop.getVideoStock(),
                    getBasket(),
                    uig_offer /*Verknpfung Gate und Formsheet */,
                    null,
                    null,
                    false,
                    new TEDVideoStock(),
                    null,
                    csdbs);

		
        
		//aussehen des Formsheet mit dem ContenCreator anpassen; in diesem Fall zwei neue Button setzen
        ttfs_rent.addContentCreator(new RentTTFSContentCreator());        
        
		return uig_offer;
	}
    
    public Gate restart(){
       return getInitialGate();
    }
    
    
	/**
	 * @return a <code>Gate</code> where the money gets inserted
	 */
    

	public Gate getPayGate() {
   
       
       
        NumberValue nv_sum = (NumberValue) getContext().getProcessData(SUM_KEY);
		CCSStrategy ccss = new CCSStrategy();
		ccss.setErrorHandler(FormSheetStrategy.MSG_POPUP_ERROR_HANDLER);
        
        UIGate uig_pay = new UIGate(null, null);
		
        //FormSheet erzeugen
        TwoTableFormSheet ttfs_pay =
            TwoTableFormSheet.create(
                "Throw the money in the slot, please.",
                VideoShop.getCurrency(),
                (MoneyBag)getContext().getProcessData(MB_TEMP_KEY),
                getBasket(),
                uig_pay,
                new ComparatorCurrency(),
                new ComparatorCurrency(),
                false,
                null,
                null,
                ccss);
        // ContentCreator erstellen
        RentPayFSContentCreator formSheetCC = new RentPayFSContentCreator(this);
        
        //so kann man dem Formsheet bestehende Daten mitgeben! z.b. um Eingabefelder schon zu befllen
        formSheetCC.setPayValue(VideoShop.getCurrency().toString(nv_sum));
        
        ttfs_pay.addContentCreator(formSheetCC);
        
        return uig_pay;
	}
 
 
	/**
	 * @return a <code>Gate</code> where the selected videos and the change money is shown
	 */
	public Gate getConfirmGate() {
       
       UIGate uig_confirm = new UIGate(null, null);
       getBasket().setCurrentSubBasket(SUB_SHOP_VIDEO);
       SingleTableFormSheet fs =
            SingleTableFormSheet.create(
                "Confirm your transaction!",
                getBasket(),
                uig_confirm,
                DataBasketConditionImpl.allStockItemsWithDest(
                        ((AutomatUser) ((SalesPoint) getContext()).getUser()).getVideoStock()),
                new DefaultStoringStockDBETableEntryDescriptor());
              
       fs.addContentCreator(new RentConfirmFSContentCreator(this, uig_confirm));
       uig_confirm.setFormSheet(fs);
       return uig_confirm;
	}
	
    
}

