package videoautomat;
import java.io.IOException;
import java.util.Iterator;

import log.Log;
import log.LogNoOutputStreamException;
import data.StockItem;
import data.events.StockChangeAdapter;
import data.events.StockChangeEvent;
/**
 * This class implements a StockChangeListener, which reacts to changes on {@link AutomatUser#getVideoStock()}. It writes
 * such events as rent or give back event to the global logfile.
 *  
 */
public class StockChangeLogger extends StockChangeAdapter {

	/*
	 * The ID of the owner of the stock this listener belongs to
	 */
	private String user_ID;

	/**
	 * Constructs a new StockChangeLogger
	 * 
	 * @param user_ID
	 *                  the ID of the owner of the stock this listener should be add to
	 */
	public StockChangeLogger(String user_ID) {
		this.user_ID = user_ID;
	}

	/**
	 * Called whenever the adding of <code>StockItems</code> was commited. Logs it as a rent-event.
	 * 
	 * @see data.events.StockChangeListener#commitAddStockItems(data.events.StockChangeEvent)
	 */
	public void commitAddStockItems(StockChangeEvent event) {
		Iterator it = event.getAffectedItems();
		while (it.hasNext()) {
			try {
				Log.getGlobalLog().log(
					new LoggableImpl(
						user_ID,
						((StockItem) it.next()).getName(),
						true));
			} catch (LogNoOutputStreamException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
	}

	/**
	 * Called whenever the removing of <code>StockItems</code> was commited. Logs it as a hand back-event.
	 * 
	 * @see data.events.StockChangeListener#commitRemoveStockItems(data.events.StockChangeEvent)
	 */
	public void commitRemoveStockItems(StockChangeEvent event) {
		Iterator it = event.getAffectedItems();
		while (it.hasNext()) {
			try {
				Log.getGlobalLog().log(
					new LoggableImpl(
						user_ID,
						((StockItem) it.next()).getName(),
						false));
			} catch (LogNoOutputStreamException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
	}
}
