package videoautomat;

import util.swing.AbstractTableEntryDescriptor;

/**
 * This class implements a TableEntryDescriptor used to display rented {@link VideoCassette}s
 *  
 */
public class TEDVideoCassette extends AbstractTableEntryDescriptor {

	/**
	 * @return the number of columns each record will consist of.
	 * 
	 * @see util.swing.TableEntryDescriptor#getColumnCount()
	 */
	public int getColumnCount() {
		return 3;
	}

	/**
	 * @return the text to be printed in the header of the given column.
	 * @param nIdx
	 *                  the index of the column for which to return the header. Indices run from 0 to
	 *                  {@link TEDVideoCassette#getColumnCount()}- 1.
	 * @see util.swing.TableEntryDescriptor#getColumnName(int)
	 */
	public String getColumnName(int nIdx) {
		switch (nIdx) {
			case 0 :
				return "Title";
			case 1 :
				return "Days";
			case 2 :
				return "Cost";
		}
		return null;
	}

	/**
	 * @return the class of objects that make up the values of cells of the given column. This will be used to
	 *              determine the cell renderer and editor unless you specify otherwise through
	 *              util.swing.AbstractTableEntryDescriptor#getCellEditor(int) and
	 *              util.swing.AbstractTableEntryDescriptor#getCellRenderer(int).
	 * @param nIdx
	 *                  the index of the column for which to return the header. Indices run from 0 to
	 *                  {@link TEDVideoCassette#getColumnCount()}- 1.
	 * @see util.swing.TableEntryDescriptor#getColumnClass(int)
	 */
	public Class getColumnClass(int nIdx) {
		switch (nIdx) {
			case 0 :
				return String.class;
			case 1 :
				return Integer.class;
			case 2 :
				return String.class;
		}
		return null;
	}

	/**
	 * @return the value to be printed in the given column for the given record. The actual class must be a subclass of
	 *              what was returned by {@link TEDVideoCassette#getColumnClass(int)}or that class itself.
	 * @param nIdx
	 *                  the index of the column for which to return the header. Indices run from 0 to
	 *                  {@link TEDVideoCassette#getColumnCount()}- 1.
	 * @see util.swing.TableEntryDescriptor#getValueAt(java.lang.Object, int)
	 */
	public Object getValueAt(Object oRecord, int nIdx) {
		VideoCassette vc = (VideoCassette) oRecord;
		switch (nIdx) {
			case 0 :
				return vc.getName();
			case 1 :
				return new Integer(vc.getDays());
			case 2 :
				return VideoShop.getCurrency().toString(vc.getCost());
		}
		return null;
	}
}
