package videoautomat;
import javax.swing.table.TableCellRenderer;

import util.swing.AbstractTableEntryDescriptor;
import data.NumberValue;
import data.QuoteValue;
import data.swing.CountingStockTableModel;
import data.swing.CurrencyRenderer;

/**
 * This class implements a TableEntryDescriptor used to display the {@link VideoShop#getVideoStock()} 
 */
public class TEDVideoStock extends AbstractTableEntryDescriptor {

    private String[] cNames = { "Name", "Price", "Count" };
    private Class[] cClasses = { String.class, NumberValue.class, Integer.class };    
    CurrencyRenderer renderer = new CurrencyRenderer(VideoShop.getCurrency());
	/**
	 * @return the number of columns each record will consist of.
	 * 
	 * @see util.swing.TableEntryDescriptor#getColumnCount()
	 */
	public int getColumnCount() {
		return 3;
	}

	/**
	 * @return the text to be printed in the header of the given column.
	 * @param nIdx
	 *                  the index of the column for which to return the header. Indices run from 0 to
	 *                  {@link TEDVideoStock#getColumnCount()}- 1.
	 * @see util.swing.TableEntryDescriptor#getColumnName(int)
	 */
	public String getColumnName(int nIdx) {
		return cNames[nIdx];
	}

	/**
	 * @return the class of objects that make up the values of cells of the given column. This will be used to
	 *              determine the cell renderer and editor unless you specify otherwise through
	 *              util.swing.AbstractTableEntryDescriptor#getCellEditor(int) and
	 *              util.swing.AbstractTableEntryDescriptor#getCellRenderer(int).
	 * @param nIdx
	 *                  the index of the column for which to return the header. Indices run from 0 to
	 *                  {@link TEDVideoStock#getColumnCount()}- 1.
	 * @see util.swing.TableEntryDescriptor#getColumnClass(int)
	 */
	public Class getColumnClass(int nIdx) {
		return cClasses[nIdx];
	}

	/**
	 * @return the value to be printed in the given column for the given record. The actual class must be a subclass of
	 *              what was returned by {@link TEDVideoStock#getColumnClass(int)}or that class itself.
	 * @param nIdx
	 *                  the index of the column for which to return the header. Indices run from 0 to
	 *                  {@link TEDVideoStock#getColumnCount()}- 1.
	 * @see util.swing.TableEntryDescriptor#getValueAt(java.lang.Object, int)
	 */
	public Object getValueAt(Object oRecord, int nIdx) {
		CountingStockTableModel.Record r = (CountingStockTableModel.Record) oRecord;
		switch (nIdx) {
			case 0 :
				return r.getDescriptor().getName();
			case 1 :
				return ((QuoteValue) r.getDescriptor().getValue()).getOffer();
			case 2 :
				return new Integer(r.getCount());
		}
		return null;
	}

	/**
	 * @return the cell renderer to be used for cells in the given column.
	 * @param nIdx
	 *                  the index of the column for which to return the header. Indices run from 0 to
	 *                  {@link TEDVideoStock#getColumnCount()}- 1.
	 * @see util.swing.TableEntryDescriptor#getCellRenderer(int)
	 */
	public TableCellRenderer getCellRenderer(int nIdx) {
		switch (nIdx) {
			case 1 :
				return renderer;
		}
		return super.getCellRenderer(nIdx);
	}
}
