package videoautomat.contentcreator;
import java.awt.Color;
import java.awt.GridLayout;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JPasswordField;
import javax.swing.JTextArea;
import javax.swing.JTextField;

import sale.FormSheet;
import sale.FormSheetContentCreator;
import videoautomat.contentcreator.stdactions.RollBackAction;
import videoautomat.contentcreator.stdactions.TransitWithAction;
import videoautomat.transition.RegisterOKTransition;

/**
 * Content creator of the register process. Contains methods to set and add data 
 * independly from the gui part.
 *
 * @author Tobias Ruch
 */
public class RegisterContentCreator extends FormSheetContentCreator {   

   /** Textarea for the error message */
   private JTextArea errorMessage;
   /** Label with the initial massage */
   private JLabel message;
   /** Textfield for the user name */
   private JTextField userName;
   /** PasswordField for the 1st password */
   private JPasswordField password;
   /** PasswordField for the 2nd password */
   private JPasswordField confirmedPassword;   
   /**
    * Creates a new content creator with an initial message
    * @param message - initial message
    */
   public RegisterContentCreator(String message){
      
      //initialize components
      errorMessage      = new JTextArea();
      this.message      = new JLabel();
      userName          = new JTextField();
      password          = new JPasswordField();
      confirmedPassword = new JPasswordField();      
      //set initial values
      this.message.setText(message);
      errorMessage.setForeground(Color.RED);
      errorMessage.setBackground(this.message.getBackground());
      //errorMessage.setEnabled(false);
      errorMessage.setEditable(false);
   }   
   
   /**
    * Method will be called from the FormSheet to which this ContentCreator is added.
    * So the Attribut fs will be this FormSheet.
    * You have to bild the content of your formsheet in this method
    * @param fs - FormSheet to which this ContentCreator was added.
    */
   protected void createFormSheetContent(FormSheet fs) {    
      fs.removeAllButtons();
      
      
      //settings to Panels
      JComponent component    = new JPanel();
      JComponent outerPanel   = new JPanel(); // a Panal with flow layout for optimal size of added components
      JComponent messagePanel = new JPanel(new GridLayout(0,1));
      JComponent inputPanel   = new JPanel(new GridLayout(0,2,5,15));      
      component.setLayout(new BoxLayout(component, BoxLayout.Y_AXIS)); 
      //?----outerPanel-------?
      //|?---component-------?|
      //||?-----------------?||
      //|||    message      |||
      //||?-----------------?||
      //||?-----------------?||
      //|||    input        |||
      //||?-----------------?||
      //|?-------------------?|
      //?---------------------?
      
      
      messagePanel.add(errorMessage);
      messagePanel.add(message);
      
      inputPanel.add(new JLabel("User Name"));
      inputPanel.add(userName);
      inputPanel.add(new JLabel("Password"));
      inputPanel.add(password);
      inputPanel.add(new JLabel("Confirm Password"));
      inputPanel.add(confirmedPassword);
      
      component.add(messagePanel);
      component.add(Box.createVerticalStrut(30));
      component.add(inputPanel);
      
      outerPanel.add(component);
      // set Buttons; using standard action to set transition classes
      fs.addButton("OK", 1, new TransitWithAction(new RegisterOKTransition(this)));
      fs.addButton("Cancel", 2, new RollBackAction());
      
      fs.setComponent(outerPanel);      
   }   

   
   /**
    * Returns the value of the username.
    * @return - the username
    */
   public String getUserName(){
      return userName.getText();
   }
   
   /**
    * Returns the value of the password.
    * @return - the value of the password as an char array
    */
   public char[] getPassword(){
      return password.getPassword();
   }
   
   /**
    * Returns the value of the confirmed password.
    * @return - the value of the password as an char array
    */
   public char[] getConfirmedPassword(){
      return confirmedPassword.getPassword();
   }
   
   /**
    * Sets the value of the username
    * @param userName - value of the username
    */
   public void setUserName(String userName){
      this.userName.setText(userName);
   }
   
   /**
    * Sets the error message to this formsheet.
    * @param message - an error massage.
    */
   public void setErrorMessage(String message){
      errorMessage.setText(message);
   }   
   
}
