package videoautomat.contentcreator;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;

import sale.FormSheet;
import sale.FormSheetContentCreator;
import sale.FormSheet.FormButton;
import videoautomat.SaleProcessRent;
import videoautomat.contentcreator.stdactions.TransitWithAction;
import videoautomat.transition.RentPayConfirmTransition;
import videoautomat.transition.RentPayRollbackTransition;
import data.CatalogItemValue;
import data.DataBasket;
import data.IntegerValue;
import data.NumberValue;
import data.events.StockChangeAdapter;
import data.events.StockChangeEvent;
import data.ooimpl.MoneyBagImpl;
/**
 * Changes the FormSheet layout and adds some labels and a listener
 * to change the pay button state.
 *
 * @author Tobias Ruch
 */
public class RentPayFSContentCreator extends FormSheetContentCreator {   
   /** String of the pay value */
   private String payValue;
   /** Process in which the FormSheet and so the content creator is used */
   private SaleProcessRent processRent;
   
   /**
    * Creates the content creator.
    * @param process - <code>SaleProcessRent</code> in which the ContentCreator is use to have access to some
    *                     process data 
    */
   public RentPayFSContentCreator(SaleProcessRent process){
      this.processRent = process;
      payValue = "";
   }
   
   /**
   * Changes the FormSheetContent of the gives <code>FormSheet</code>.
   * Adds labels, button and there actions
   * @param fs - a <code>FormSheet</code> which should be changed.
   */
   protected void createFormSheetContent(FormSheet fs) {      
      JComponent jc = new JPanel();
      jc.setLayout(new BoxLayout(jc, BoxLayout.Y_AXIS));
      jc.add(Box.createVerticalStrut(10));
      jc.add(new JLabel("You have to pay: " + payValue));
      jc.add(Box.createVerticalStrut(10));
      jc.add(fs.getComponent());
      
      fs.setComponent(jc);
      fs.removeAllButtons();
        
      fs.addButton("Pay", 1, new TransitWithAction(new RentPayConfirmTransition()));

      fs.addButton("Cancel", 2, new TransitWithAction(new RentPayRollbackTransition()));
      fs.getButton(1).setEnabled(false);
      setButtonStockListener(fs.getButton(1));
   }    

   
   public void setPayValue(String payValue){
      this.payValue = payValue;
   }   
   /**
     * Adds an implementation of the <code>StockChangeListener</code> to the given button, so that this button gets
     * enabled if there is enough money in the temporar-moneybag and otherwise it gets disabled
     * 
     * @param fb
     *                  the <code>FormButton</code> the listener should en/disable
     */
   private void setButtonStockListener(final FormButton fb) {
      final MoneyBagImpl bag = (MoneyBagImpl) processRent.getContext().getProcessData(SaleProcessRent.MB_TEMP_KEY);
      final DataBasket basket = processRent.getBasket();
      final NumberValue nv_sum = (NumberValue) processRent.getContext().getProcessData(SaleProcessRent.SUM_KEY);
      
      //new StockChangeApdater, which is extended by an anonymous class 
      //which overrides the addedStockItems method
      
      StockChangeAdapter sca = new StockChangeAdapter() {
         public void addedStockItems(StockChangeEvent e) {
            
            
            if (bag.sumStock(basket, new CatalogItemValue(), new IntegerValue(0))
                  .compareTo(nv_sum)>= 0){
               fb.setEnabled(true);
            }
         }
         public void removedStockItems(StockChangeEvent e) {
            if (bag.sumStock(basket, new CatalogItemValue(), new IntegerValue(0))
                  .compareTo(nv_sum) < 0){
               fb.setEnabled(false);
            }
         }
      };
      
      bag.addStockChangeListener(sca);
   }  
}
