package videoautomat.contentcreator.stdactions;
import sale.Action;
import sale.SaleProcess;
import sale.SalesPoint;
import data.DataBasket;

/**
 * Standart action to start an {@link sale.SaleProcess}.
 *
 * @author Tobias Ruch
 */
public class RunProcessAction implements Action {

   /** instance of the process which should be started by this action. */
   private SaleProcess process;
   
   private DataBasket basket;
   
   
   /**
    * Constructs a new action to start the process.
    * @param process - {@link sale.SaleProcess} which should be started by this action.
    */
   public RunProcessAction(SaleProcess process) {
      this.process = process;
   }
   
   /**
    * Constructs a new action to start the process.
    * @param process - {@link sale.SaleProcess} which should be started by this action.
    * @param basket - {@link data.ooimpl.DataBasket} attached to the process.
    */
   public RunProcessAction(SaleProcess process, DataBasket basket)
   {
       this.process = process;
       this.basket = basket;
   }

   /**
    * Applies the action and start the given process.
    * @param saleProcess - current {@link sale.SaleProecess}
    * @param salePoint   - current {@link sale.SalesPoint}
    */
   public void doAction(SaleProcess saleProcess, SalesPoint salePoint) throws Throwable {
      if(basket != null)
          salePoint.runProcess(process, basket);
      else
          salePoint.runProcess(process);
   }

}
