package videoautomat.transition;

import sale.Gate;
import sale.SaleProcess;
import sale.SalesPoint;
import sale.Transition;
import users.User;
import users.stdforms.LogOnForm;
import videoautomat.SaleProcessLogOn;

/**
 * a <code>Transition</code> that proves the selected name and password and with success leads to the
 * {@link SaleProcessLogOn#getMainGate()}, otherwise it returns the
 * {@link SaleProcessLogOn#getFaultGate()}.
 * 
 * @author Alexander Herrmann
 *
 */
public class LogOnTransition implements Transition {
    
    private LogOnForm lof;
    
    /**
     * Constructor for referencing the <code>LogOnForm</code>
     * @param lof
     */
    public LogOnTransition(LogOnForm lof)
    {
        this.lof = lof;
    }
    
    /**
     * Proves the user and its password. If successful registeres user, puts user to
     * <code>ProcessContext</code> and redirects to {@link SaleProcessLogOn#getMainGate()}.
     * Otherwise returns to {@link SaleProcessLogOn#getFaultGate()}.
     * @param sp - the current <code>SaleProcess</code>
     * @param user - the current <code>User</code>
     */
    public Gate perform(SaleProcess sp, User user) {
        
        SaleProcessLogOn processLogOn = (SaleProcessLogOn) sp;
        lof.ok();
        User user_current = lof.getResult();
        
        if(user_current != null)
        {
            ((SalesPoint) processLogOn.getContext()).attach(user_current);
            return processLogOn.getMainGate();
        }
        
        return processLogOn.getFaultGate();
    }

}
