package videoautomat.transition;

import java.util.Arrays;

import sale.FormSheet;
import sale.Gate;
import sale.SaleProcess;
import sale.Transition;
import sale.UIGate;
import users.User;
import users.UserManager;
import videoautomat.AutomatUser;
import videoautomat.contentcreator.RegisterContentCreator;
/**
 * Transition to register a new {@link users.User}.
 *
 * @author Tobias Ruch
 */
public class RegisterOKTransition implements Transition {

   /** Referenz the the given {@link RegisterContentCreator}*/

   private RegisterContentCreator creator;

   /**
    * Construts a new <code>RegisterOKTransition</code> with the given ContentCreator
    * from wich the Transition is called.
    * @param creator - <code>RegisterContentCreator</code> which calls this {@link sale.Transition}
    */
   public RegisterOKTransition(RegisterContentCreator creator) {
      this.creator = creator;
   }
   /**
    * Implemeneted from the <code>Transition</code>-Interface to perform the registration
    * @param sp - the process that triggered the Transition
    * @param user - the user currently active in the process' ProcessContext
    */
   public Gate perform(SaleProcess sp, User user) {
      //input validation

      StringBuffer errors = new StringBuffer("");

      // if no user name
      if ("".equals(creator.getUserName())){
         errors.append("You have to choose a user name!\n");
      }

      //different passwords
      if (!Arrays.equals(creator.getPassword(), creator.getConfirmedPassword())){
         errors.append("The passwords are different!\n");

      }

      if (UserManager.getGlobalUM().getUserNames().contains(creator.getUserName())){
         errors.append("User already exists!\n");
      }

      // an error occurred
      if (errors.length() != 0){
         // set error message
         creator.setErrorMessage(errors.toString());
         // create new formsheet and reuse the old Content Creator
         FormSheet register = new FormSheet("Register", creator, false);
         // return the gate
         return new UIGate(register, null);
      }


      //everything is ok: create the new user
      UserManager.getGlobalUM().addUser(new AutomatUser(creator.getUserName(), creator.getPassword(), false));

      // return the commit gate
      return sp.getCommitGate();
   }

}
