package videoautomat.transition;

import java.util.Iterator;

import data.CatalogItemValue;
import data.DataBasket;
import data.DataBasketConditionImpl;
import data.IntegerValue;
import data.MoneyBag;
import data.NotEnoughMoneyException;
import data.NumberValue;
import data.StoringStock;
import data.ooimpl.CountingStockItemDBEntry;
import sale.Gate;
import sale.SaleProcess;
import sale.SalesPoint;
import sale.Transition;
import users.User;
import videoautomat.AutomatUser;
import videoautomat.DisplayMoneyStockError;
import videoautomat.SaleProcessRent;
import videoautomat.VideoCassette;
import videoautomat.VideoShop;

/**
 *<code>Transition</code> that temporary adds the selected videos to the
 *{@link AutomatUser#getVideoStock()}, the inserted money to the {@link VideoShop#getVideoStock()}
 *and from there transacts the change money
 * @author Tobias Ruch
 */

public class RentPayConfirmTransition implements Transition {   

   /**
    * Performes the transition.
    * @param sp - current process
    * @param user - current user of this process
    * 
    * @return the new <code>Gate</code> which should be shown after the transition    
    */     
   
   public Gate perform(SaleProcess sp, User user) {      

      
      SaleProcessRent saleProcess = (SaleProcessRent) sp;
      DataBasket dataBasket = saleProcess.getBasket();
      MoneyBag mb_temp = (MoneyBag) saleProcess.getContext().getProcessData(SaleProcessRent.MB_TEMP_KEY);
      /*
       * first add new rent-cassettes to the user`s stock
       */
      
      
      dataBasket.setCurrentSubBasket(SaleProcessRent.SUB_USER_VIDEO);
      StoringStock ss_user =
         ((AutomatUser) ((SalesPoint) saleProcess.getContext()).getUser())
         .getVideoStock();
      
      Iterator i =
         dataBasket.subBasketIterator(
               SaleProcessRent.SUB_SHOP_VIDEO,
               DataBasketConditionImpl.ALL_ENTRIES);
      while (i.hasNext()) {
         VideoCassette vc =
            new VideoCassette(
                  ((CountingStockItemDBEntry) i.next())
                  .getSecondaryKey());
         ss_user.add(vc, dataBasket);
      }      
      /*
       * calculate what is in the temporar moneybag
       */
      
      dataBasket.setCurrentSubBasket(SaleProcessRent.SUB_TMP_MONEY);
      NumberValue nv = (NumberValue)((NumberValue) mb_temp.sumStock(dataBasket,
            new CatalogItemValue(),
            new IntegerValue(0))).
            subtract((NumberValue)saleProcess.getContext().getProcessData(SaleProcessRent.SUM_KEY));       
      /*
       * this prevents an exception that is caused by removing all items from the table
       * while it is shown
       */
      try {
         saleProcess.getContext().setFormSheet(saleProcess, null);
      } catch (InterruptedException e1) {
         e1.printStackTrace();
      }      
      /*
       * put the content of the temporar moneybag to the shop`s one and get the change
       */
      VideoShop.getMoneyBag().addStock(mb_temp, dataBasket, true);
      dataBasket.setCurrentSubBasket(SaleProcessRent.SUB_SHOP_MONEY);
      try{	
         VideoShop.getMoneyBag().transferMoney(mb_temp, dataBasket, nv);					
      }catch(NotEnoughMoneyException e){
         dataBasket.rollbackSubBasket(SaleProcessRent.SUB_USER_VIDEO);
         dataBasket.rollbackSubBasket(SaleProcessRent.SUB_TMP_MONEY);
         dataBasket.rollbackSubBasket(SaleProcessRent.SUB_SHOP_MONEY);
         DisplayMoneyStockError dmse = new DisplayMoneyStockError();
         dataBasket.setCurrentSubBasket(SaleProcessRent.SUB_TMP_MONEY);
         return saleProcess.getPayGate();
      }
      
      return saleProcess.getConfirmGate();       
      
   }   
   
}
