package videoautomat.transition;
import sale.Gate;
import sale.SaleProcess;
import sale.Transition;
import users.User;
import videoautomat.SaleProcessRent;
import videoautomat.VideoShop;
import data.BasketEntryValue;
import data.CatalogItem;
import data.DataBasket;
import data.DataBasketEntry;
import data.IntegerValue;
import data.NumberValue;
import data.QuoteValue;
import data.Value;
import data.events.VetoException;

/**
 * <code>Transition</code> that sums up the prices of the selected videos and leads to the
 *     {@link SaleProcessRent#getPayGate()}, if no video is selected it leads to the
 *     {@link SaleProcessRent#getInitialGate()}
 *
 * @author Tobias Ruch
 */
public class RentSumUpTransition implements Transition {   
 
   /**
    * Performes the transition.
    * @param sp - current process
    * @param user - current user of this process
    * 
    * @return the new <code>Gate</code> which should be shown after the transition    
    */ 
   public Gate perform(SaleProcess sp, User user) {
      
     
      NumberValue nv_sum = (NumberValue) sp.getBasket().sumSubBasket(
                             SaleProcessRent.SUB_SHOP_VIDEO,
                             null, 
                             new SumBasketEntryValue(sp.getBasket()), 
                             new IntegerValue(0));
      sp.getContext().setProcessData(SaleProcessRent.SUM_KEY, nv_sum);
      if (nv_sum.isAddZero()){
         return ((SaleProcessRent)sp).restart();
      }
      
      sp.getBasket().setCurrentSubBasket(SaleProcessRent.SUB_TMP_MONEY);
      return ((SaleProcessRent)sp).getPayGate();
   }   
   
   /**
    * Inner class to create a <code>BasketEntryValue</code> implemenation
    * and to avoid anonymous classes and inline declarations.
    *
    * @author Tobias Ruch
    */
   private static class SumBasketEntryValue implements BasketEntryValue{
      /** DataBasket which sould be summed */
      private DataBasket dataBasket;
      
      /**
       * Creates a new instance
       * @param db - DataBasket, which should be summed up.
       */
      public SumBasketEntryValue(DataBasket db){
         this.dataBasket = db;
      }
      
      public Value getEntryValue(DataBasketEntry dbe) {
         try {
            CatalogItem ci = VideoShop.getVideoCatalog().get(
                  dbe.getSecondaryKey(),null, false);
            
            int count = ((Integer) dbe.getValue()).intValue();
            
            return ((QuoteValue) ci.getValue()).getOffer().multiply(count);
            
         } catch (VetoException e) {
            e.printStackTrace();
            dataBasket.rollback();
         }
         return null;
      }
   }      
}
